from .version import *
from .project import Project
from .circle_api import get_latest_build, get_artifact_list
import argparse
from fnmatch import fnmatch
from urllib.request import urlretrieve

API_ROOT = 'https://circleci.com/api/v1'

def main():
    arguments = argparse.ArgumentParser(description=SHORT_DESCRIPTION)
    arguments.add_argument('--version', action='version', version='%(prog)s ' + VERSION)
    arguments.add_argument('--api-root', type=str, help='API root for CircleCI',
                           default=API_ROOT)
    arguments.add_argument('--token', type=str, help='API key', nargs='?')
    arguments.add_argument('username', type=str, help='GitHub username')
    arguments.add_argument('project', type=str, help='GitHub project')
    arguments.add_argument('artifact', type=str,
                           help='Artifact name (or pattern) to get',
                           nargs='*', default=['*'])
    arguments.add_argument('--branch', type=str,
                           help='Project branch', default='master')
    arguments.add_argument('--accept-failed', action='store_true',
                           help='Accepts artifacts from the latest build')
    arguments.add_argument('--build', type=int, default=None,
                           help='Go to a specific build')
    args = arguments.parse_args()
    project = Project(username = args.username,
                      project  = args.project,
                      api_root = args.api_root,
                      token    = args.token)
    build = args.build
    if build is None:
        build = get_latest_build(project, args.branch, args.accept_failed)
    artifacts = get_artifact_list(project, build)
    for name, url in artifacts.items():
        if any(fnmatch(name, pattern) for pattern in args.artifact):
            print('Downloading {}...'.format(name), end='')
            urlretrieve(url, filename=name)
            print('{}[DONE]'.format(' '*(60 - len(name))))




import requests
from urllib.parse import urljoin

from .project import Project

def get_latest_build(project, branch, allow_failures=False):
    filt = 'completed' if allow_failures else 'successful'
    target = '{root}/project/{user}/{project}/tree/{branch}?limit=1&filter={filt}'.format(
                root=project.api_root,
                user=project.username,
                project=project.project,
                branch=branch,
                filt=filt)
    if project.token is not None:
        target += '&circle-token={}'.format(project.token)
    data = requests.get(target, headers={'Accept': 'application/json'})
    output = data.json()
    if len(output) == 0:
        raise ValueError('No matching builds.')
    return output[0]['build_num']

def get_artifact_list(project, build):
    target = '{root}/project/{user}/{project}/{build}/artifacts'.format(
                root=project.api_root,
                user=project.username,
                project=project.project,
                build=build)
    if project.token is not None:
        target += '?circle-token={}'.format(project.token)
    data = requests.get(target, headers={'Accept': 'application/json'})
    output = data.json()
    return {x['pretty_path'][18:]: x['url'] for x in output}




import sys
import re

if sys.version < '3.4':
    print('Sorry, this is not a compatible version of Python. Use 3.4 or later.')
    exit(1)

from setuptools import setup, find_packages

with open('README.md') as f:
    description = f.read()
    description = re.sub(r'\[!\[.+\].+\]\(.+\)', '', description)
    description = '\n'.join(description.splitlines()[2:])
    description = re.sub('\n{2,}', '\n\n', description).strip()

from circle_asset.version import VERSION, SHORT_DESCRIPTION

setup(name='circle-asset',
      version=VERSION,
      description=SHORT_DESCRIPTION,
      author='Alistair Lynn',
      author_email='arplynn@gmail.com',
      license="MIT",
      long_description=description,
      url='https://github.com/prophile/circle-asset',
      zip_safe=True,
      setup_requires=['nose >=1, <2'],
      install_requires=[
          'requests >=2.5, <3'
      ],
      entry_points={'console_scripts': [
          'circle-asset=circle_asset.cli:main'
      ]},
      packages=find_packages(),
      test_suite='nose.collector')

